@@ -29,7 +29,7 @@
 
 #include "properties.h"
 #include "gameconfig.h"
-#include "gnobots.h"
+#include "gnome-robots.h"
 #include "graphics.h"
 #include "gbdefs.h"
 #include "keyboard.h"
@@ -76,7 +76,7 @@ struct _GnobotsProperties {
   GdkRGBA bgcolour;
   gint selected_config;
   guint keys[N_KEYS];
-  gchar *themename;
+  const gchar *themename;
 };
 /**********************************************************************/
 
@@ -185,7 +185,7 @@ pmap_selection (GtkWidget * widget, gpointer data)
 
   conf_set_theme (properties.themename);
 
-  set_game_graphics (properties.themename);
+  load_game_graphics ();
   clear_game_area ();
 }
 
@@ -350,14 +350,14 @@ make_theme_menu (void)
 static void
 bg_color_callback (GtkWidget * widget, gpointer data)
 {
-  gtk_color_button_get_rgba (GTK_COLOR_BUTTON (widget),
+  gtk_color_chooser_get_rgba (GTK_COLOR_CHOOSER (widget),
 			      &properties.bgcolour);
   set_background_color (properties.bgcolour);
   clear_game_area ();
   conf_set_background_color (&properties.bgcolour);
 }
 
-gchar *
+const gchar *
 properties_theme_name (void)
 {
   return properties.themename;
@@ -391,10 +391,9 @@ show_properties_dialog (void)
   if (propbox)
     return;
 
-  propbox = gtk_dialog_new_with_buttons (_("Robots Preferences"),
-					 GTK_WINDOW (app),
-					 GTK_DIALOG_DESTROY_WITH_PARENT,
-					 GTK_STOCK_CLOSE, GTK_RESPONSE_ACCEPT,
+  propbox = gtk_dialog_new_with_buttons (_("Preferences"),
+					 GTK_WINDOW (window),
+					 GTK_DIALOG_USE_HEADER_BAR,
 					 NULL);
   gtk_container_set_border_width (GTK_CONTAINER (propbox), 5);
   gtk_box_set_spacing (GTK_BOX (gtk_dialog_get_content_area (GTK_DIALOG (propbox))), 2);
@@ -470,7 +469,7 @@ show_properties_dialog (void)
 
   label = gtk_label_new_with_mnemonic (_("_Image theme:"));
   gtk_widget_set_hexpand (label, TRUE);
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+  gtk_widget_set_halign (label, GTK_ALIGN_START);
   gtk_grid_attach (GTK_GRID (grid), label, 0, 0, 1, 1);
 
   pmapmenu = make_theme_menu ();
@@ -481,11 +480,11 @@ show_properties_dialog (void)
   gtk_grid_attach (GTK_GRID (grid), pmapmenu, 1, 0, 1, 1);
 
   label = gtk_label_new_with_mnemonic (_("_Background color:"));
-  gtk_misc_set_alignment (GTK_MISC (label), 0, 0.5);
+  gtk_widget_set_halign (label, GTK_ALIGN_START);
   gtk_grid_attach (GTK_GRID (grid), label, 0, 1, 1, 1);
 
   w = gtk_color_button_new ();
-  gtk_color_button_set_rgba (GTK_COLOR_BUTTON (w), &properties.bgcolour);
+  gtk_color_chooser_set_rgba (GTK_COLOR_CHOOSER (w), &properties.bgcolour);
   g_signal_connect (G_OBJECT (w), "color_set",
 		    G_CALLBACK (bg_color_callback), NULL);
   gtk_label_set_mnemonic_widget (GTK_LABEL (label), w);
@@ -508,14 +507,11 @@ show_properties_dialog (void)
 				    "key01", _("Key to move N"), g_settings_get_default_value (settings, "key01"),
 				    "key02", _("Key to move NE"), g_settings_get_default_value (settings, "key02"),
 				    "key03", _("Key to move W"), g_settings_get_default_value (settings, "key03"),
-                                    "key04", _("Key to hold"), g_settings_get_default_value (settings, "key04"),
+				    "key04", _("Key to hold"), g_settings_get_default_value (settings, "key04"),
 				    "key05", _("Key to move E"), g_settings_get_default_value (settings, "key05"),
 				    "key06", _("Key to move SW"), g_settings_get_default_value (settings, "key06"),
 				    "key07", _("Key to move S"), g_settings_get_default_value (settings, "key07"),
 				    "key08", _("Key to move SE"), g_settings_get_default_value (settings, "key08"),
-				    "key09", _("Key to teleport"), g_settings_get_default_value (settings, "key09"),
-				    "key10", _("Key to teleport randomly"), g_settings_get_default_value (settings, "key10"),
-				    "key11", _("Key to wait"), g_settings_get_default_value (settings, "key11"),
                                     NULL);
 
   gtk_box_pack_start (GTK_BOX (vbox), controls_list, TRUE, TRUE, 0);
@@ -538,7 +534,6 @@ show_properties_dialog (void)
   g_signal_connect (G_OBJECT (propbox), "response",
 		    G_CALLBACK (apply_cb), NULL);
 
-  gtk_window_set_modal (GTK_WINDOW (propbox), TRUE);
   gtk_widget_show_all (propbox);
 }
 
@@ -589,7 +584,7 @@ load_properties (void)
   properties.show_toolbar = g_settings_get_boolean (settings,
                                                     KEY_SHOW_TOOLBAR);
 
-  set_game_graphics (properties.themename);
+  load_game_graphics ();
   set_game_config (properties.selected_config);
   keyboard_set (properties.keys);
   return TRUE;
@@ -608,7 +603,7 @@ load_keys (void)
 }
 
 void
-conf_set_theme (gchar * value)
+conf_set_theme (const gchar * value)
 {
   g_settings_set_string (settings, KEY_THEME, value);
 }
